@@ -4,4 +4,4 @@ from uuid import uuid4
 def generate_id(prefix=""):
     if prefix != "":
         prefix += "-"
-    return f"{prefix}-{str(uuid4())}"
+    return f"{prefix}{str(uuid4())}"
